# PERSEO

### **Personal Semantics Objects**

<hr>

### **Instalation:**

Install locally after cloning the repo usingor using  [Pypi repository](https://pypi.org/project/py-perseo/):

```bash
pip install py-perseo
```

####  **Unique identifier generator:**

Milisecond timestamp for CSV spreadsheets

[Documentation here](https://github.com/pabloalarconm/PERSEO/tree/main/perseo)

<hr>

#### **N-Triples to Turtle transformation**

RDF data transformation from N-Triples representation to Turtle

[Documentation here](https://github.com/pabloalarconm/PERSEO/tree/main/perseo)




